import React, { useState } from "react";
import { DescriptiveReference } from "../../common/graph/node";
import "./nodetypeentry.css";

type ReferenceEntryProps = {
    reference: DescriptiveReference;
    onReferenceDelete: (url: string) => void;
    onReferenceChange: (
        originalUrl: string,
        reference: DescriptiveReference
    ) => void;
};

function ReferenceEntry({
    reference,
    onReferenceDelete,
    onReferenceChange,
}: ReferenceEntryProps) {
    const [editedReference, setEditedReference] =
        useState<DescriptiveReference>(reference);
    const originalUrl = reference.url;

    const onPropChange = (
        prop: keyof DescriptiveReference,
        newValue: string
    ) => {
        reference[prop] = newValue;
        setEditedReference(reference);
    };

    return (
        <div
            className="reference"
            onBlur={() => onReferenceChange(originalUrl, editedReference)}
        >
            <label htmlFor="reference-url">Url</label>
            <br />
            <input
                className="reference-url"
                type={"text"}
                value={reference.url}
                onChange={(event) => onPropChange("url", event.target.value)}
            />
            <br />
            <label htmlFor="reference-description">Description</label>
            <br />
            <textarea
                className="reference-description"
                value={reference.description}
                onChange={(event) =>
                    onPropChange("description", event.target.value)
                }
            />
            <br />
            <button onClick={() => onReferenceDelete(originalUrl)}>
                Delete
            </button>
        </div>
    );
}

export default ReferenceEntry;
