import React from "react";
import { DescriptiveReference } from "../../common/graph/node";
import "./nodetypeseditor.css";
import ReferenceEntry from "./referenceentry";

type ReferencesEditorProps = {
    references: DescriptiveReference[];
    onReferencesChange: (newReferences: DescriptiveReference[]) => void;
};

function ReferencesEditor({
    references,
    onReferencesChange,
}: ReferencesEditorProps) {
    const isUrlUnique = (url: string): boolean =>
        !references.some((ref: DescriptiveReference) => ref.url == url);

    const handleReferenceDelete = (url: string) => {
        references = references.filter(
            (ref: DescriptiveReference) => ref.url != url
        );
        onReferencesChange(references);
    };

    const handleReferenceChange = (
        url: string,
        reference: DescriptiveReference
    ) => {
        // Make sure url stays unique
        if (isUrlUnique(reference.url)) {
            console.log(
                "URL of changed reference is not unique anymore for current node. Cannot save changes on reference."
            );
            return;
        }

        const index: number = references.findIndex(
            (ref: DescriptiveReference) => ref.url == url
        );
        references[index] = reference;
        onReferencesChange(references);
    };

    const addReference = () => {
        // Make sure no empty url exists already
        // => Button only enabled if no empty url in references

        references.push({ url: "", description: "" });
        onReferencesChange(references);
    };

    return (
        <div id="references-editor">
            <label htmlFor="references-editor">References</label>
            {references.map(
                (reference: DescriptiveReference, index: number) => {
                    return (
                        <ReferenceEntry
                            key={index}
                            reference={reference}
                            onReferenceChange={handleReferenceChange}
                            onReferenceDelete={handleReferenceDelete}
                        />
                    );
                }
            )}
            <br />
            <button onClick={addReference} disabled={!isUrlUnique("")}>
                Add reference
            </button>
        </div>
    );
}

export default ReferencesEditor;
